
*DATASET #1 - HEALTH CARE EXPENDITURES IN THE UNITED STATES (IN BILLIONS) NH_TOT->NATIONAL
              TOTAL/FG_TOT->FEDERAL GOVERNMENT;
data t112;
input year nh_tot fg_tot @@;
cards;
1970 74.4 17.7 1971 82.3 20.4
1972 92.3 22.9 1973 102.5 25.2
1974 116.1 30.5 1975 132.9 36.4
1976 152.2 42.9 1977 172.0 47.6
1978 193.7 54.3 1979 217.2 61.4
1980 250.1 72.0 1981 290.2 84.0
1982 326.1 93.3 1983 358.6 103.2
1984 389.6 112.6 1985 422.6 123.6
1986 454.8 133.1 1987 494.1 144.0
1988 546.0 156.7 1989 602.8 175.0
1990 666.2 195.4 1995 990.2 322.4
2000 1309.4 416.0
;
run;

goptions reset=all;

* #1: PLOT NH_TOT VERSUS YEAR - LET SAS DESIGN THE PLOT;

proc gplot data=t112;
plot nh_tot*year;
run;
quit;

* #2: CHANGE THE PLOTTING SYMBOL AND JOIN THE POINTS; 

symbol value=dot interpol=join;

proc gplot data=t112;
plot nh_tot*year;
run;
quit;

* #3: ADD A TITLE AND FOOTNOTE;

symbol v=dot i=join;

title "NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";
footnote "Source: Health-United States-2003";

proc gplot data=t112;
plot nh_tot*year;
run;
quit;

* #4: USE A GOPTIONS STATEMENT 
      TO CONTROL THE  TEXT FONT AND HEIGHT
      (SYMBOL SIZE AFFECTED);

goptions ftext='Arial' htext=2 gunit=pct;

symbol v=dot i=join;

title "NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";
footnote "Source: Health-United States-2003";

proc gplot data=t112;
plot nh_tot*year;
run;
quit;

* DIGRESSION --- WHAT DOES H=2 MEAN;

proc gtestit;
run;

* #5: CHANGE THE HEIGHT OF THE TITLE
      RIGHT JUSTIFY THE FOOTNOTE;

goptions ftext='Arial' htext=2 gunit=pct;

symbol v=dot i=join;

title height=4 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";
footnote justify=right 
"Source: Health-United States-2003";

proc gplot data=t112;
plot nh_tot*year;
run;
quit;

* DIGRESSION --- NOW, WHAT DOES H=2 MEAN AFTER SPECIFYING GUNIT=PCT;

proc gtestit;
run;

* #6: CHANGE THE Y-AXIS LABEL
      BOTH THE CONTENT AND ANGLE;

* FIX THE X-AXIS LABEL (RESET WITH VALIDVARNAME=V7);

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct;

symbol v=dot i=join;

axis label=(angle=90 "AMOUNT (IN BILLIONS)");

title1 h=4 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";
footnote1 j=right 
"Source: Health-United States-2003";

proc gplot data=t112;
plot nh_tot*year/vaxis=axis;
format nh_tot comma.;
run;
quit;

* #7: ADDITIONAL CHANGES OF BOTH THE X AND Y AXES;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct;

symbol v=dot i=join;

axis1 label=(angle=90 "AMOUNT (IN BILLIONS)")  
      minor=(n=3);
axis2 order=(1970 to 2000 by 5) minor=(n=4);

title h=4 "NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";
footnote justify=right "Source: Health-United States-2003";

proc gplot data=t112;
plot nh_tot*year/vaxis=axis1 haxis=axis2;
format nh_tot comma.;
run;
quit;

* #8: ADD COLOR;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct ctext=green;

symbol v=dot i=join c=blue h=2.5;

axis1 label=(angle=90 "AMOUNT (IN BILLIONS)") 
      minor=(n=3) color=blue;
axis2 order=(1970 to 2000 by 5) minor=(n=4) color=blue;

title1 h=4 "NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";
footnote1 j=r "Source: Health-United States-2003";

proc gplot data=t112;
plot nh_tot*year/vaxis=axis1 haxis=axis2;
format nh_tot comma.;
run;
quit;

* #9: LEAVE ALL AXES TEXT GREEN;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct ctext=green;

symbol v=dot i=join c=blue h=2.5;

axis1 label=(angle=90 rotate=0 "AMOUNT (IN BILLIONS)")
      minor=(n=3); 
axis2 order=(1970 to 2000 by 5) 
      minor=(n=4) offset=(2,2); 

title1 h=4 f='Arial/bo' ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

* ADD SOME SPACE ON THE LEFT AND RIGHT;

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=r ls=1 "Source: Health-United States-2003  ";

proc gplot data=t112;
plot nh_tot*year/vaxis=axis1 haxis=axis2 caxis=blue;
format nh_tot comma.;
run;
quit;

* #10: ADD ANOTHER LINE TO THE PLOT;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct ctext=green;
symbol v=dot i=join c=blue h=2.5;

axis1 label=(angle=90 rotate=0 "AMOUNT (IN BILLIONS)")
      minor=(n=3); 
axis2 order=(1970 to 2000 by 5) minor=(n=4) offset=(2,2); 

title1 h=4 f='Arial/bo' ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=r ls=1 "Source: Health-United States-2003  ";

proc gplot data=t112;
plot (nh_tot fg_tot)*year/overlay 
      vaxis=axis1 haxis=axis2 caxis=blue;
format nh_tot comma.;
run;
quit;

* #11: ADD ANOTHER SYMBOL STATEMENT;

goptions reset=all;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct ctext=green;

symbol1 v=dot i=join h=2.5 l=1;
symbol2 v=dot i=join h=2.5 l=3;

axis1 label=(angle=90 rotate=0 "AMOUNT (IN BILLIONS)")
       minor=(n=3); 
axis2 order=(1970 to 2000 by 5) minor=(n=4) offset=(2,2); 

title1 h=4 f='Arial/bo' ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=r ls=1 "Source: Health-United States-2003  ";

proc gplot data=t112;
plot (nh_tot fg_tot)*year/overlay 
      vaxis=axis1 haxis=axis2 caxis=blue;
format nh_tot comma.;
run;
quit;

* #12: USE GOPTIONS AND THE CYSMBOL OPTION;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct 
         ctext=green csymbol=blue;

symbol1 v=dot i=join h=2.5 l=1;
symbol2 v=dot i=join h=2.5 l=3;

axis1 label=(angle=90 rotate=0 "AMOUNT (IN BILLIONS)")
      minor=(n=3); 
axis2 order=(1970 to 2000 by 5) minor=(n=4) offset=(2,2); 

title1 h=4 f='Arial/bo' ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=right ls=1 
"Source: Health-United States-2003  ";

proc gplot data=t112;
plot (nh_tot fg_tot)*year/overlay 
     vaxis=axis1 haxis=axis2 caxis=blue;
format nh_tot comma.;
run;
quit;

* #13: ADD A LEGEND;

options validvarname=upcase;

goptions ftext='Arial' htext=2 gunit=pct 
         ctext=green csymbol=blue;

symbol1 v=dot i=join h=2.5 l=1;
symbol2 v=dot i=join h=2.5 l=3;

axis1 label=(angle=90 rotate=0 "AMOUNT (IN BILLIONS)")
      minor=(n=3); 
axis2 order=(1970 to 2000 by 5) minor=(n=4) offset=(2,2); 

title1 h=4 f='Arial/bo' ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=r ls=1 "Source: Health-United States-2003  ";

proc gplot data=t112;
plot (nh_tot fg_tot)*year/overlay 
     vaxis=axis1 haxis=axis2 caxis=blue legend;
format nh_tot comma.;
run; 
quit;

* #14: MODIFY THE DEFAULT LEGEND;

* <NO CHANGES IN OPTIONS, GOPTIONS, SYMBOLS, AXES>;

legend1 label=none 
        value=(j=left "TOTAL" j=left "FEDERAL GOVT") 
        mode=protect position=(top inside left) 
        cborder=blue cshadow=blue 
        across=1 shape=line(10);

title1 h=4 f='Arial/bo' ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=r ls=1 "Source: Health-United States-2003  ";

proc gplot data=t112;
plot (nh_tot fg_tot)*year/overlay 
     vaxis=axis1 haxis=axis2 caxis=blue legend=legend1;
format nh_tot comma.;
run; 
quit;

***************************************************************************;

* ANNOTATE DATA SET WITH SPECIAL VARIABLE NAMES;

data labels;
retain xsys ysys '2' function 'label' 
       position '1'  style '"Tahoma/bo" '
       color 'blue'  cborder 'blue';

* find last observation in data set t112;
set t112 nobs=lastrec point=lastrec;

text=' FEDERAL GOVERNMENT '; x=year; y=fg_tot; output;
text=' TOTAL '             ; x=year; y=nh_tot; output;

stop;
run;

proc print data=labels;
run;

* #16 USE ANNOTATION TO LABEL THE LINES;

options validvarname=upcase;

goptions ftext='Tahoma/bo' htext=2 gunit=pct 
         ctext=green csymbol=blue;

symbol1 f=marker v='C' i=join h=1.25;
symbol2 f=marker v='U' i=join h=1.25;

axis1 label=(angle=90 rotate=0 "AMOUNT (IN BILLIONS)")
      minor=(n=3); 
axis2 order=(1970 to 2000 by 5) minor=(n=4) offset=(2,2); 

title1 h=4 ls=1 
"NATIONAL HEALTH CARE EXPENDITURES: 1970-2000";

title2 h=2 a=90; 
title3 h=2 a=270;

footnote j=right ls=1 "Source: Health-United States-2003  ";

proc gplot data=t112;
plot (nh_tot fg_tot)*year/overlay 
      vaxis=axis1 haxis=axis2 caxis=blue annotate=labels; 
format nh_tot comma.;
run; 
quit;

***************************************************************************;


*** PROC GREPLAY TO DISPLAY MORE THAN PLOT PER PAGE;

*** make up some data;

data test;
input year a b c d;
datalines;
1990 10 10 10 10
1991 20 25 30 35
1993 30 35 55 75
;
run;

*** set GOPTIONS;

goptions reset=all ftext='Tahoma' gunit=pct htext=4 border;

symbol1 i=j;

*** create 4 plots - use GOUT= and NAME= options;

proc gplot data=test gout=PLOTS;
title h=4 'PLOT A';
plot a*year / name='plota';
run;
title h=4 'PLOT B';
plot b*year / name='plotb';
run;
title h=4 'PLOT C';
plot c*year / name='plotc';
run;
title h=4 'PLOT D';
plot d*year / name='plotd';
run;
quit;

*** replay plots;

proc greplay igout=plots nofs;
*** use a SAS-supplied template;
tc sashelp.templt;
template l2r2;
tplay 2:plotb 4:plotd 1:plota 3:plotc;

*** use a user-defined template;
tdef four 1/llx=0   ulx=25  lrx=100 urx=75
            lly=0   uly=40  lry=0   ury=40
          2/llx=0   ulx=0   lrx=25  urx=25
            lly=0   uly=100 lry=40  ury=90
          3/llx=75  ulx=75  lrx=100 urx=100
            lly=40  uly=90  lry=0   ury=100
          4/llx=25  ulx=25  lrx=75  urx=75
            lly=40  uly=90  lry=40  ury=90  ;
 
template  four;
tplay 2:plota 4:plotb 1:plotd 3:plotc;
quit;

*** clear catalog;

proc catalog cat=plots kill;
quit;
